SmartAlertDialogTheme class
A theme class for customizing the appearance of the SmartAlertDialog.
Constructors
- SmartAlertDialogTheme({Color? backgroundColor, Color? titleTextColor, Color? messageTextColor, BorderRadius? buttonsBorderRadius, Color? confirmButtonTextColor, Color? confirmButtonBackgroundColor, Color? cancelButtonTextColor, Color? cancelButtonBackgroundColor, SmartAlertDialogButtonAlignment? buttonAlignment})
-
const
Properties
- backgroundColor → Color?
-
final
-
final
-
final
- cancelButtonBackgroundColor → Color?
-
final
- cancelButtonTextColor → Color?
-
final
- confirmButtonBackgroundColor → Color?
-
final
- confirmButtonTextColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageTextColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleTextColor → Color?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited